8. dynamic — Jscatter 1.2.0 documentation

# 8. dynamic

## 8.1. Transform between domains

`shiftAndBinning` |
`time2frequencyFF` |

## 8.2. Time domain

`resolution` |
`simpleDiffusion` |
`doubleDiffusion` |
`cumulantDiff` |
`cumulant` |
`cumulantDLS` |
`finiteRouse` |
`finiteZimm` |
`integralZimm` |
`stretchedExp` |
`jumpDiffusion` |
`methylRotation` |
`diffusionHarmonicPotential` |
`diffusionPeriodicPotential` |
`rotDiffusion` |
`zilmanGranekBicontinious` |
`zilmanGranekLamellar` |

## 8.3. Frequency domain

`h` |
`getHWHM` |
`convolve` |
`dynamicSusceptibility` |
`resolution_w` |
`elastic_w` |
`transDiff_w` |
`jumpDiff_w` |
`diffusionHarmonicPotential_w` |
`diffusionInSphere_w` |
`rotDiffusion_w` |
`nSiteJumpDiffusion_w` |